@@ -22,7 +22,7 @@ def setup_logging(log_level=logging.INFO):
     """Set up the logging."""
     logging.basicConfig(level=log_level)
     fmt = "%(asctime)s %(levelname)s (%(threadName)s) " "[%(name)s] %(message)s"
-    colorfmt = "%(log_color)s{}%(reset)s".format(fmt)
+    colorfmt = f"%(log_color)s{fmt}%(reset)s"
     datefmt = '%Y-%m-%d %H:%M:%S'
 
     # Suppress overly verbose logs from libraries that aren't helpful
@@ -350,10 +350,9 @@ class Dispatcher:
             device = self.abode.get_device(device_id)
 
             if device:
-                # pylint: disable=protected-access
                 print(
                     json.dumps(
-                        device._json_state,
+                        device._state,
                         sort_keys=True,
                         indent=4,
                         separators=(',', ': '),
