@@ -1,5 +1,7 @@
 import logging
 
+from jaraco.collections import DictAdapter, Projection
+
 from ..exceptions import AbodeException
 
 from ..helpers import constants as CONST
@@ -13,23 +15,32 @@ _LOGGER = logging.getLogger(__name__)
 class AbodeDevice:
     """Class to represent each Abode device."""
 
-    def __init__(self, json_obj, abode):
+    def __init__(self, state, abode):
         """Set up Abode device."""
-        self._json_state = json_obj
-        self._device_id = json_obj.get('id')
-        self._device_uuid = json_obj.get('uuid')
-        self._name = json_obj.get('name')
-        self._type = json_obj.get('type')
-        self._type_tag = json_obj.get('type_tag')
-        self._generic_type = json_obj.get('generic_type')
+        self._state = state
         self._abode = abode
 
-        self._update_name()
+    def __getattr__(self, name):
+        if name in '_name _type _type_tag _generic_type'.split():
+            name = name.lstrip('_')
+
+        try:
+            return self._state[name]
+        except KeyError as exc:
+            raise AttributeError(name) from exc
+
+    @property
+    def _device_id(self):
+        return self.id
+
+    @property
+    def _device_uuid(self):
+        return self.uuid
 
     @needs_control_url
     def set_status(self, status):
         """Set device status."""
-        path = self._json_state['control_url']
+        path = self._state['control_url']
 
         status_data = {'status': str(status)}
 
@@ -53,7 +64,7 @@ class AbodeDevice:
     @needs_control_url
     def set_level(self, level):
         """Set device level."""
-        url = self._json_state['control_url']
+        url = self._state['control_url']
 
         level_data = {'level': str(level)}
 
@@ -79,7 +90,7 @@ class AbodeDevice:
         from if it has the data you require.
         This data is updated by the subscription service.
         """
-        return self._json_state.get(name.lower(), {})
+        return self._state.get(name.lower(), {})
 
     def refresh(self, path=CONST.DEVICE_URL):
         """Refresh the devices json object data.
@@ -104,18 +115,9 @@ class AbodeDevice:
     def update(self, json_state):
         """Update the json data from a dictionary.
 
-        Only updates if it already exists in the device.
+        Only updates keys already present.
         """
-        self._json_state.update(
-            {k: json_state[k] for k in json_state if self._json_state.get(k)}
-        )
-        self._update_name()
-
-    def _update_name(self):
-        """Set the device name from _json_state, with a sensible default."""
-        self._name = self._json_state.get('name')
-        if not self._name:
-            self._name = self.type + ' ' + self.device_id
+        self._state.update(Projection(self._state, json_state))
 
     @property
     def status(self):
@@ -125,28 +127,29 @@ class AbodeDevice:
     @property
     def battery_low(self):
         """Is battery level low."""
-        return int(self.get_value('faults').get('low_battery', '0')) == 1
+        return bool(int(self.get_value('faults').get('low_battery', '0')))
 
     @property
     def no_response(self):
         """Is the device responding."""
-        return int(self.get_value('faults').get('no_response', '0')) == 1
+        return bool(int(self.get_value('faults').get('no_response', '0')))
 
     @property
     def out_of_order(self):
         """Is the device out of order."""
-        return int(self.get_value('faults').get('out_of_order', '0')) == 1
+        return bool(int(self.get_value('faults').get('out_of_order', '0')))
 
     @property
     def tampered(self):
         """Has the device been tampered with."""
         # 'tempered' - Typo in API?
-        return int(self.get_value('faults').get('tempered', '0')) == 1
+        return bool(int(self.get_value('faults').get('tempered', '0')))
 
     @property
     def name(self):
         """Get the name of this device."""
-        return self._name
+        fallback = f'{self.type} {self.device_id}'
+        return self._state.get('name') or fallback
 
     @property
     def generic_type(self):
@@ -176,7 +179,5 @@ class AbodeDevice:
     @property
     def desc(self):
         """Get a short description of the device."""
-        # Garage Entry Door (ZW:00000003) - Door Lock - Closed
-        return '{0} (ID: {1}, UUID: {2}) - {3} - {4}'.format(
-            self.name, self.device_id, self.device_uuid, self.type, self.status
-        )
+        tmpl = '{name} (ID: {device_id}, UUID: {device_uuid}) - {type} - {status}'
+        return tmpl.format_map(DictAdapter(self))
