@@ -55,7 +55,7 @@ class AbodeEventController:
 
         _LOGGER.debug("Subscribing to Abode connection updates for: %s", unique_id)
 
-        self._connection_status_callbacks[unique_id].append((callback))
+        self._connection_status_callbacks[unique_id].append(callback)
 
         return True
 
@@ -92,7 +92,7 @@ class AbodeEventController:
 
             _LOGGER.debug("Subscribing to updates for device_id: %s", device_id)
 
-            self._device_callbacks[device_id].append((callback))
+            self._device_callbacks[device_id].append(callback)
 
         return True
 
@@ -138,7 +138,7 @@ class AbodeEventController:
 
             _LOGGER.debug("Subscribing to event group: %s", event_group)
 
-            self._event_callbacks[event_group].append((callback))
+            self._event_callbacks[event_group].append(callback)
 
         return True
 
@@ -161,7 +161,7 @@ class AbodeEventController:
 
             _LOGGER.debug("Subscribing to timeline event: %s", timeline_event)
 
-            self._timeline_callbacks[event_code].append((callback))
+            self._timeline_callbacks[event_code].append(callback)
 
         return True
 
@@ -177,7 +177,6 @@ class AbodeEventController:
 
     def _on_socket_started(self):
         """Socket IO startup callback."""
-        # pylint: disable=W0212
         cookies = self._abode._get_session().cookies.get_dict()
         cookie_string = "; ".join([str(x) + "=" + str(y) for x, y in cookies.items()])
 
@@ -189,7 +188,6 @@ class AbodeEventController:
 
         try:
             self._abode.refresh()
-        # pylint: disable=W0703
         except Exception as exc:
             _LOGGER.warning("Captured exception during Abode refresh: %s", exc)
         finally:
@@ -249,8 +247,7 @@ class AbodeEventController:
         # At the time of development, refreshing after mode change notification
         # didn't seem to get the latest update immediately. As such, we will
         # force the mode status now to match the notification.
-        # pylint: disable=W0212
-        alarm_device._json_state['mode']['area_1'] = mode
+        alarm_device._state['mode']['area_1'] = mode
 
         for callback in self._device_callbacks[alarm_device.device_id]:
             _execute_callback(callback, alarm_device)
@@ -304,6 +301,5 @@ def _execute_callback(callback, *args, **kwargs):
     # Callback with some data, capturing any exceptions to prevent chaos
     try:
         callback(*args, **kwargs)
-    # pylint: disable=W0703
     except Exception as exc:
         _LOGGER.warning("Captured exception during callback: %s", exc)
