@@ -134,9 +134,7 @@ class TestCamera:
         """Tests that camera devices capture new images."""
         for device in self.camera_devices():
             # Remove control URLs from JSON
-            device._json_state = DictFilter(
-                device._json_state, include_pattern='(?!control_url)'
-            )
+            device._state = DictFilter(device._state, include_pattern='(?!control_url)')
 
             # Test that AbodeException is raised with no control URLs
             with pytest.raises(AbodeException) as exc:
@@ -255,7 +253,7 @@ class TestCamera:
             assert device.image_to_file(path, get_image=True)
 
             # Test the file written and cleanup
-            image_data = open(path, "r").read()
+            image_data = open(path).read()
             assert image_response, image_data
             os.remove(path)
 
